Learn R Programming

OpenTreeChronograms (version 2022.1.28)

tnrs_match: Taxon name resolution service (tnrs) applied to a vector of names by batches

Description

Taxon name resolution service (tnrs) applied to a vector of names by batches

Usage

tnrs_match(input, reference_taxonomy, tip, ...)

# S3 method for default tnrs_match(input, reference_taxonomy = "otl", ...)

# S3 method for phylo tnrs_match(input, reference_taxonomy = "otl", tip = NULL, ...)

Arguments

input

A character vector of taxon names, or a phylo object with tip names, to be matched to taxonomy.

reference_taxonomy

A character vector specifying the reference taxonomy to use for tnrs.

tip

A vector of mode numeric or character specifying the tips to match. If left empty all tips will be matched.

...

Arguments passed on to rotl::tnrs_match_names

context_name

name of the taxonomic context to be searched (length-one character vector or NULL). Must match (case sensitive) one of the values returned by tnrs_contexts. Default to "All life".

do_approximate_matching

A logical indicating whether or not to perform approximate string (a.k.a. “fuzzy”) matching. Using FALSE will greatly improve speed. Default, however, is TRUE.

ids

A vector of ids to use for identifying names. These will be assigned to each name in the names array. If ids is provided, then ids and names must be identical in length.

include_suppressed

Ordinarily, some quasi-taxa, such as incertae sedis buckets and other non-OTUs, are suppressed from TNRS results. If this parameter is true, these quasi-taxa are allowed as possible TNRS results.

Value

An object of class data frame or phylo, with the added class match_names.

NULL

NULL

Details

There is no limit to the number of names that can be queried and matched.

The output will preserve all elements from original input phylo object and will add

phy$mapped

A character vector indicating the state of mapping of phy$tip.labels:

original
Tnrs matching was not attempted. Original labeling is preserved.
ott
Matching was manually made by a curator in Open Tree of Life.
tnrs
Tnrs matching was attempted and successful with no approximate matching. Original label is replaced by the matched name.
approximated
Tnrs matching was attempted and successful but with approximate matching. Original labeling is preserved.
unmatched
Tnrs matching was attempted and unsuccessful. Original labeling is preserved.

phy$original.tip.label

A character vector preserving all original labels.

phy$ott_ids

A numeric vector with ott id numbers of matched tips. Unmatched and original tips will be NaN.

if tips are duplicated, tnrs will only be run once (avoiding increases in function running time) but the result will be applied to all duplicated tip labels

Examples

Run this code
# NOT RUN {
tnrs_match(input = c("Mus"))
tnrs_match(input = c("Mus", "Mus musculus"))
tnrs_match(input = c("Mus", "Echinus", "Hommo", "Mus"))
# }

Run the code above in your browser using DataLab